@@ -3,8 +3,7 @@ from typing import Any, AsyncIterator, Optional, Type, TypeVar, cast
 
 from fastapi import Depends, FastAPI, Request
 
-from flexdi import FlexGraph
-from flexdi.scope import ApplicationScope, RequestScope
+from flexdi import ApplicationScope, FlexGraph, RequestScope
 
 T = TypeVar("T")
 
@@ -35,8 +34,6 @@ class FastAPIGraph(FlexGraph):
 
         @app.on_event("startup")
         async def startup() -> None:
-            await self.open()
-            stack.push_async_callback(self.close)
             nonlocal app_scope
             app_scope = self.application_scope()
             await app_scope.open()
